@@ -14,7 +14,7 @@ class FastStridePianist(Instrument):
 
 	def generate_note(self, state):
 
-		if state["tick"] % (state["resolution"] / 2) == 0 \
+		if state["tick"] % (state["resolution"] / 2.0) == 0 \
 				and random() < 5.0 * state["wild"]:
 			if random() > 0.1:
 				n = Note(state["chord"][0])
@@ -28,7 +28,7 @@ class FastStridePianist(Instrument):
 			n.octave_down()
 			return [n]
 		
-		if state["tick"] % (state["resolution"] / 2) == \
+		if state["tick"] % (state["resolution"] / 2.0) == \
 				state["resolution"] / 4 \
 				and random() < 5.0 *state["wild"]:
 			c = state["chord"]
