@@ -78,8 +78,8 @@ class Sequencer:
 		self.chords = progressions.to_chords( \
 				self.progression, self.key)
 		self.state["chords"] = self.chords
-		self.ticks = self.resolution / self.meter[1] \
-				* self.meter[0]
+		self.ticks = int(round(self.resolution / \
+				float(self.meter[1]) * self.meter[0]))
 
 
 	def play_instruments(self):
